@@ -20,31 +20,31 @@
 #define ECBUILD_VERSION "3.9.1"
 #endif
 #ifndef ECBUILD_MACROS_DIR
-#define ECBUILD_MACROS_DIR  "C:/M/B/src/eccodes-2.40.0-Source/cmake"
+#define ECBUILD_MACROS_DIR  "C:/W/B/src/eccodes-2.40.0-Source/cmake"
 #endif
 
 /* config info */
 
-#define ECCODES_OS_NAME          "Windows-6.2.9200"
+#define ECCODES_OS_NAME          "Windows-10.0.26200"
 #define ECCODES_OS_BITS          64
 #define ECCODES_OS_BITS_STR      "64"
 #define ECCODES_OS_STR           "windows.64"
-#define ECCODES_OS_VERSION       "6.2.9200"
+#define ECCODES_OS_VERSION       "10.0.26200"
 #define ECCODES_SYS_PROCESSOR    "ARM64"
 
 #define ECCODES_BUILD_TIMESTAMP  ""
 #define ECCODES_BUILD_TYPE       "Release"
 
 #define ECCODES_C_COMPILER_ID      "Clang"
-#define ECCODES_C_COMPILER_VERSION "20.1.0"
+#define ECCODES_C_COMPILER_VERSION "21.1.8"
 
 #define ECCODES_CXX_COMPILER_ID      "Clang"
-#define ECCODES_CXX_COMPILER_VERSION "20.1.0"
+#define ECCODES_CXX_COMPILER_VERSION "21.1.8"
 
-#define ECCODES_C_COMPILER       "C:/msys64/clangarm64/bin/clang.exe"
+#define ECCODES_C_COMPILER       "C:/M/msys64/clangarm64/bin/clang.exe"
 #define ECCODES_C_FLAGS          "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-implicit-function-declaration -pipe -O3 -DNDEBUG"
 
-#define ECCODES_CXX_COMPILER     "C:/msys64/clangarm64/bin/clang++.exe"
+#define ECCODES_CXX_COMPILER     "C:/M/msys64/clangarm64/bin/clang++.exe"
 #define ECCODES_CXX_FLAGS        "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -pipe -O3 -DNDEBUG"
 
 /* Needed for finding per package config files */
@@ -54,18 +54,18 @@
 #define ECCODES_INSTALL_LIB_DIR   "/clangarm64/lib"
 #define ECCODES_INSTALL_DATA_DIR  "/clangarm64/share/eccodes"
 
-#define ECCODES_DEVELOPER_SRC_DIR "C:/M/B/src/eccodes-2.40.0-Source"
-#define ECCODES_DEVELOPER_BIN_DIR "C:/M/B/src/build-CLANGARM64"
+#define ECCODES_DEVELOPER_SRC_DIR "C:/W/B/src/eccodes-2.40.0-Source"
+#define ECCODES_DEVELOPER_BIN_DIR "C:/W/B/src/build-CLANGARM64"
 
 /* Fortran support */
 
-#if 0
+#if 1
 
-#define ECCODES_Fortran_COMPILER_ID      ""
-#define ECCODES_Fortran_COMPILER_VERSION ""
+#define ECCODES_Fortran_COMPILER_ID      "LLVMFlang"
+#define ECCODES_Fortran_COMPILER_VERSION "21.1.8"
 
-#define ECCODES_Fortran_COMPILER ""
-#define ECCODES_Fortran_FLAGS    ""
+#define ECCODES_Fortran_COMPILER "C:/M/msys64/clangarm64/bin/flang.exe"
+#define ECCODES_Fortran_FLAGS    " -O3"
 
 #endif
 
